@@ -118,26 +118,36 @@ static void changed_part_combo(GtkWidget *widget, gpointer data){
                          COL_PART, UTF8_MEISHI,
                          -1);
       selected_word->part = NOUN;
+      gtk_widget_show(noun_option_pane);
+      gtk_widget_hide(adv_option_pane);
     }else if(strcmp(text,UTF8_FUKUSHI) == 0){
       gtk_list_store_set(wordlist, &iter,
                          COL_PART, UTF8_FUKUSHI,
                          -1);
       selected_word->part = ADVERB;
+      gtk_widget_hide(noun_option_pane);
+      gtk_widget_show(adv_option_pane);
     }else if(strcmp(text,UTF8_JINNMEI) == 0){
       gtk_list_store_set(wordlist, &iter,
                          COL_PART, UTF8_JINNMEI,
                          -1);
       selected_word->part = PERSON;
+      gtk_widget_hide(noun_option_pane);
+      gtk_widget_hide(adv_option_pane);
     }else if(strcmp(text,UTF8_CHIMEI) == 0){
       gtk_list_store_set(wordlist, &iter,
                          COL_PART, UTF8_CHIMEI,
                          -1);
       selected_word->part = PLACE;
+      gtk_widget_hide(noun_option_pane);
+      gtk_widget_hide(adv_option_pane);
     }else if(strcmp(text,UTF8_KEIYOUSHI) == 0){
       gtk_list_store_set(wordlist, &iter,
                          COL_PART, UTF8_KEIYOUSHI,
                          -1);
       selected_word->part = ADJECTIVE;
+      gtk_widget_hide(noun_option_pane);
+      gtk_widget_hide(adv_option_pane);
     }
     
     free(text);
@@ -480,7 +490,7 @@ int create_top_window()
   g_signal_connect(G_OBJECT(freq_spin),"value-changed",
                    G_CALLBACK(changed_freq_spin),NULL);
 
-  /* creating spin button for "Part of Speech" */
+  /* creating combo box for "Part of Speech" */
   label = gtk_label_new(_("Part of Speech"));
   alignment = gtk_alignment_new(0,0.5,0,0);
   gtk_container_add(GTK_CONTAINER(alignment),GTK_WIDGET(label));
@@ -596,6 +606,6 @@ int create_top_window()
   gtk_widget_hide(noun_option_pane);
   gtk_widget_hide(adv_option_pane);
   
-  return 0;
+  return 1;
 
 }
